/*******************************************************************************
 * Copyright (c) 2004 Actuate Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Actuate Corporation  - initial API and implementation
 *******************************************************************************/

package org.eclipse.birt.report.tests.viewer.regression;

import java.io.ByteArrayInputStream;
import java.io.InputStream;

import org.apache.cactus.WebRequest;
import org.eclipse.birt.report.servlet.ViewerServlet;
import org.eclipse.birt.report.tests.viewer.BaseViewerTestCase;

import com.meterware.httpunit.WebResponse;

/**
 * <b>Bug Description:</b>
 * <p>
 * Data indent happens gradually on each detail row when preview attached file
 * with one group including two header rows in html.
 * <p>
 * <b>Steps to reproduce:</b>
 * <p>
 * preview attached file in html
 * <p>
 * <b>Result:</b>
 * <p>
 * Data indent happens gradually on each detail row <b>Note:</b>
 * <p>
 * It throws out an exception in viewer but RunTask and RenderTask to run the
 * attached design and successful create the report
 * <p>
 * <b>Test Description:</b>
 * <p>
 * Run the report, no exception thrown out
 * 
 */
public class Regression_120334 extends BaseViewerTestCase
{

	private final static String REPORT = "report/Regression_120334.rptdesign"; //$NON-NLS-1$

	/**
	 * Set request url for Regression_120334.rptdesign
	 * 
	 * @param webRequest
	 */

	public void begin_regression_120334( WebRequest webRequest )
	{

		webRequest.setURL( null, null, SERVLET_PATH_FRAMESET, null, null );
		webRequest.addParameter( PARAM_REPORT, REPORT );
		webRequest.addHeader( "request-type", "SOAP" );//$NON-NLS-1$//$NON-NLS-2$
		webRequest.setContentType( "text/xml; charset=utf-8" ); //$NON-NLS-1$
		webRequest.addHeader( "SOAPAction", "''" ); //$NON-NLS-1$//$NON-NLS-2$
		webRequest.setUserData( getSoapStream( ) );
	}

	/**
	 * Process "/frameset" request
	 */
	public void test_regression_120334( )
	{
		ViewerServlet servlet = new ViewerServlet( );
		try
		{
			servlet.init( config );
			servlet.doPost( request, response );
		}
		catch ( Exception e )
		{
			e.printStackTrace( );
			fail( e.toString( ) );
		}
	}

	/**
	 * @param webResponse
	 */
	public void end_regression_120334( WebResponse webResponse )
	{
		assertEquals( 200, webResponse.getResponseCode( ) );

	}

	private InputStream getSoapStream( )
	{
		String soapMessage = "<Envelope xmlns=\"http://schemas.xmlsoap.org/soap/envelope/\"><Body><GetUpdatedObjects xmlns=\"http://schemas.eclipse.org/birt\"><Operation><Target><Id>Document</Id><Type>Document</Type></Target><Operator>GetPage</Operator><Oprand><Name>page</Name><Value>1</Value></Oprand><Oprand><Name>svg</Name><Value>false</Value></Oprand></Operation></GetUpdatedObjects></Body></Envelope>"; //$NON-NLS-1$
		return new ByteArrayInputStream( soapMessage.getBytes( ) );
	}

}
